package com.example.testktor.ViewModel

import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateMapOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.testktor.Category
import com.example.testktor.SneakerCategoryResponse
import com.example.testktor.getSneakers
import io.ktor.client.HttpClient
import io.ktor.client.engine.android.Android
import kotlinx.coroutines.launch

class MainViewModel : ViewModel() {
    var sneakersCategories by mutableStateOf(SneakerCategoryResponse(emptyList(), emptyList()))
        private set

    var selectedCategory by mutableStateOf<Category?>(null)

    var likedSneakers = mutableStateMapOf<Int, Boolean>()

    private val client = HttpClient(Android)

    init {
        viewModelScope.launch {
            sneakersCategories = getSneakers(client) ?: SneakerCategoryResponse(emptyList(), emptyList())
        }
    }

    fun toggleLike(sneakerId: Int) {
        likedSneakers[sneakerId] = !(likedSneakers[sneakerId] ?: false)
    }

    fun isLiked(sneakerId: Int): Boolean {
        return likedSneakers[sneakerId] ?: false
    }

    fun refreshData() {
        viewModelScope.launch {
            sneakersCategories = getSneakers(client) ?: SneakerCategoryResponse(emptyList(), emptyList())
        }
    }
}